@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Test::Warnings; # git description: v0.021-8-g8fb33bb
+package Test::Warnings; # git description: v0.022-4-g2f1e3f3
 # ABSTRACT: Test for warnings and the lack of them
 # KEYWORDS: testing tests warnings
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 
 use parent 'Exporter';
 use Test::Builder;
@@ -53,7 +53,13 @@ $SIG{__WARN__} = sub {
     else
     {
         $forbidden_warnings_found++;
-        goto &$_orig_warn_handler if $_orig_warn_handler;
+
+        # TODO: this doesn't handle blessed coderefs... does anyone care?
+        goto &$_orig_warn_handler if $_orig_warn_handler
+            and (  (ref $_orig_warn_handler eq 'CODE')
+                or ($_orig_warn_handler ne 'DEFAULT'
+                    and $_orig_warn_handler ne 'IGNORE'
+                    and defined &{$_orig_warn_handler}));
 
         if ($_[0] =~ /\n$/) {
             warn $_[0];
@@ -148,7 +154,7 @@ Test::Warnings - Test for warnings and the lack of them
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
